<?php
namespace Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Modules\Parametros\Services\GQL01600ParametrosGestaoQualificacaoService;

class GQL01600ParametrosGestaoQualificacaoController 
{
    
    public function __construct(GQL01600ParametrosGestaoQualificacaoService $service)
    {
        $this->service = $service;
    }
    
    /*************
     * Tab Geral *
     *************/
    
    public function retornaDadosTabGerais(DTO\Request $request, DTO\Response $response)
    {
		try {
			$row = [];
			
			$grupoOperador = $this->getGrupoOperadorCadastrado();
			
			$this->addPropertiesToRow($grupoOperador, $row);
			
			$response->addDataSet(new DataSet('data', $row));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function getGrupoOperadorCadastrado()
	{
		$grupoOperador = $this->service->findGrupoOperadorCadastrado();
		
		return $grupoOperador ? $grupoOperador[0] : $grupoOperador;
	}
	
	public function saveGrupoOperador(DTO\Request $request, DTO\Response $response)
	{
		try {
            $row = $request->getRow();
            
            $this->service->deleteGrupoOcoAtual();
            
            if ($row['DSGRUPOPER']) {
				$this->service->insertGrupoOco($row);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	/***************
     * Tab Unidade *
     ***************/
    
	public function saveOpcoesUnidade(DTO\Request $request, DTO\Response $response)
	{
		try {
			$row = $request->getRow();
			
            $this->service->acmUpdParamQualid($row);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	/*************
     * Utilities *
     *************/
    
    public function addPropertiesToRow($data, &$row) {
		foreach ($data as $propName => $value) {
			$row[$propName] = $value;
		}
	}
}
